@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.9   update date: 2024-06-20
+# Version : 1.4.10   update date: 2024-06-28
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -25,12 +25,14 @@ do
     -n) USER_SERV="$2";   shift 2 ;;
     -c) USER_CPU="$2";    shift 2 ;;
     -m) USER_MEM="$2";    shift 2 ;;
-    -t) USER_INST="$2";   shift 2 ;;	
+    -t) USER_INST="$2";   shift 2 ;;
+    -a) SECNEED="$2";     shift 2 ;;
     *)
         cat <<EOF
 Usage:
     AutoInit_GBase8s.sh [-d path] [-i path] [-p path] [-s y|n] [-l locale] [-u user] [-o y|n] 
-	                    [-n servername] [-c num_of_cpu] [-m num_of_memory] [-t type_of_instance]
+                        [-n servername] [-c num_of_cpu] [-m num_of_memory] [-t type_of_instance]
+                        [-a y|n]
 
         -d path    The path of dbspace.
         -i path    The path of install software.
@@ -43,6 +45,7 @@ Usage:
         -c NUM     Number of CPU use.
         -m NUM     Number of MB Memory use.
         -t TYPE    Type of instance will install, [small], if use this, ignore -c and -m. 
+        -a y|n     Security need, default N.
 
 EOF
         exit 1
@@ -70,6 +73,7 @@ PORTNO=9088
 PORTSSL=9089
 DATADIR=${DATADIR:-/data/gbase}
 DBS1GB=${DBS1GB:-n}
+SECNEED=${SECNEED:-n}
 
 TMP_USER_CPU=$(echo ${USER_CPU} | sed 's/[0-9]//g')
 if [ ! x"${TMP_USER_CPU}" = x ]; then
@@ -222,10 +226,7 @@ if [ $? -gt 0 ]; then
   echo "Create user [${USER_NAME}] error."
   exit 3
 fi
-passwd ${USER_NAME} <<EOF >/dev/null 2>&1
-${USER_PASS}
-${USER_PASS}
-EOF
+echo "${USER_NAME}:${USER_PASS}" | chpasswd 2>/dev/null
 mkdir -p ${USER_HOME}/users 2>/dev/null
 chmod 0755 ${USER_HOME} 2>/dev/null
 chown ${USER_NAME}:${USER_NAME} ${USER_HOME} 2>/dev/null
@@ -544,6 +545,7 @@ sed -i "s#^DUMPSHMEM.*#DUMPSHMEM 0#g" $CFGFILE
 sed -i "s#^OPT_GOAL.*#OPT_GOAL 0#g" $CFGFILE
 sed -i "s#^TAPEBLK.*#TAPEBLK 512#g" $CFGFILE
 sed -i "s#^LTAPEBLK.*#LTAPEBLK 512#g" $CFGFILE
+sed -i "s#^ALARMPROGRAM.*#ALARMPROGRAM \$GBASEDBTDIR/etc/log_full.sh#g" $CFGFILE
 
 if [ $NUMMEM -le 4096 ]; then
   sed -i "s#^DS_TOTAL_MEMORY.*#DS_TOTAL_MEMORY 128000#g" $CFGFILE
@@ -568,12 +570,65 @@ fi
 
 chown ${USER_NAME}:${USER_NAME} $CFGFILE
 
+### set audit 
+if [[ x"${SECNEED}" = xy || x"${SECNEED}" = xY ]]; then
+  _loginfo "Create group dbaao and user dbaao ."
+  groupadd dbaao 2>/dev/null
+  if [ $? -gt 0 ]; then 
+    _loginfo "Create group dbaao error !"
+  fi
+  useradd -g dbaao -d ${TMPUSER_HOME}/dbaao -m -s /bin/bash dbaao 2>/dev/null
+  if [ $? -gt 0 ]; then 
+    _loginfo "Create user dbaao error !"
+  fi
+
+  _loginfo "Create group dbsso and user dbsso ."
+  groupadd dbsso 2>/dev/null
+  if [ $? -gt 0 ]; then 
+    _loginfo "Create group dbsso error !"
+  fi
+  useradd -g dbsso -d ${TMPUSER_HOME}/dbsso -m -s /bin/bash dbsso 2>/dev/null
+  if [ $? -gt 0 ]; then 
+    _loginfo "Create user dbsso error !"
+  fi
+
+  _loginfo "Change permission for user directory."
+  chgrp -R dbaao ${INSTALL_DIR}/aaodir 2>/dev/null
+  chgrp -R dbsso ${INSTALL_DIR}/dbssodir 2>/dev/null
+  echo "IXUSERS=*" > ${INSTALL_DIR}/dbssodir/seccfg
+  chown ${USER_NAME}:dbsso ${INSTALL_DIR}/dbssodir/seccfg 2>/dev/null
+
+  mkdir -p ${TMPUSER_HOME}/dbaao/aaodir 2>/dev/null
+  chmod 0755 ${TMPUSER_HOME}/dbaao/aaodir 2>/dev/null
+  chown dbaao:dbaao ${TMPUSER_HOME}/dbaao/aaodir 2>/dev/null
+  chmod 0750 ${TMPUSER_HOME}/dbaao 2>/dev/null
+  chmod 0750 ${TMPUSER_HOME}/dbsso 2>/dev/null  
+
+  cp ${USER_HOME}/.bash_profile ${TMPUSER_HOME}/dbaao/.bash_profile 2>/dev/null
+  chown dbaao:dbaao ${TMPUSER_HOME}/dbaao/.bash_profile 2>/dev/null
+  cp ${USER_HOME}/.bash_profile ${TMPUSER_HOME}/dbsso/.bash_profile 2>/dev/null
+  chown dbsso:dbsso ${TMPUSER_HOME}/dbaao/.bash_profile 2>/dev/null
+
+  _loginfo "Set audit on."  
+  sed -i "s#^ADTMODE.*#ADTMODE 1#g" ${INSTALL_DIR}/aaodir/adtcfg
+  sed -i "s#/usr/${USER_NAME}/aaodir#${TMPUSER_HOME}/dbaao/aaodir#g" ${INSTALL_DIR}/aaodir/adtcfg
+
+  _loginfo "Set trust file."
+  sed -i "s#^REMOTE_SERVER_CFG.*#REMOTE_SERVER_CFG host.trust#g" ${CFGFILE}
+  echo "+ gbasedbt" > ${INSTALL_DIR}/etc/host.trust
+  chown ${USER_NAME}:${USER_NAME} ${INSTALL_DIR}/etc/host.trust 2>/dev/null
+  chmod 0644 ${INSTALL_DIR}/etc/host.trust 2>/dev/null
+ fi
+
 ####### restart database
 _loginfo "Restart GBase 8s Database Server."
 su - ${USER_NAME} -c "timeout 1800 onmode -ky"
 sleep 5
 su - ${USER_NAME} -c "oninit -vy"
 if [ $? -eq 0 ]; then
+  _loginfo "Set audit mask."
+  su - dbsso -c "onaudit -a -u _default -e +DRDB,DRTB,ALTB,TCTB,STSN" 2>/dev/null
+
   _loginfo "Finish."
 else
   _loginfo "Restart Server with ERROR. Please reduce the memory parameters(SHMVIRTSIZE,BUFFPOOLS), and then restart the server."
